# AIDepotPythonClient

AIDepot provides fast access to AI at scale, at affordable prices.

This python client can be used to access all of AIDepot's offerings.

To get started with the client, please see the [Client Examples Notebook](./ClientExamples.ipynb).

Please see https://aidepot.net/api/schema/swagger-ui/ for the live API documentation.
